@@ -582,6 +582,7 @@ vinagre_connection_split_string (const gchar *uri,
   gchar **server, **url;
   gint    lport;
   gchar  *lhost;
+  gboolean is_ipv6;
   gchar   ipv6_host[255] = {0,};
   VinagreProtocol *ext;
 
@@ -618,6 +619,11 @@ vinagre_connection_split_string (const gchar *uri,
       return FALSE;
     }
 
+  is_ipv6 = g_strstr_len (lhost, -1, ":") != NULL;
+
+  if (is_ipv6)
+    lhost = g_strconcat ("[", lhost, "]", NULL);
+
   if (lhost[0] == '[')
     {
       int i;
